Add example metadata handler implementation

Specialize metadata handler function template to depict implementation
of this interface.

Change-Id: I398db9c0bf1e0649ce7745d67f3345263ef1abcd
Signed-off-by: Deepak Kodihalli <dkodihal@in.ibm.com>
diff --git a/elog_meta.hpp b/elog_meta.hpp
index 9fc591d..0c3c353 100644
--- a/elog_meta.hpp
+++ b/elog_meta.hpp
@@ -24,7 +24,7 @@
 /** @brief Build error associations specific to metadata. Specialize this
  *         template for handling a specific type of metadata.
  *  @tparam M - type of metadata
  *  @param [in] data - metadata to be handled
  *  @param [in] data - metadata key=value entries
  *  @param [out] list - list of error association objects
  */
@@ -33,6 +33,16 @@
            const std::vector<std::string>& data,
            AssociationList& list) = delete;
 
+// Example template specialization - we don't want to do anything
+// for this metadata.
+using namespace example::xyz::openbmc_project::Example::Elog;
+template <>
+inline void build<TestErrorTwo::DEV_ID>(const std::string& match,
+                                        const std::vector<std::string>& data,
+                                        AssociationList& list)
+{
+}
+
 } // namespace associations
 } // namespace metadata
 } // namespace logging
@@ -24,7 +24,7 @@
  *         template for handling a specific type of metadata.
  *  @tparam M - type of metadata
- *  @param [in] data - metadata to be handled
+ *  @param [in] match - metadata to be handled
  *  @param [in] data - metadata key=value entries
  *  @param [out] list - list of error association objects